==> telescope.1.4.zip: source/Telescope/include/TelescopeSurface.h <==
/*
 * Copyright (C) 2020 Activision Publishing, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * 3. Neither the name of Activision Publishing, Inc. nor the names of
 *    its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef TELESCOPESURFACE_INCLUDE
#define TELESCOPESURFACE_INCLUDE

#include "ClientWrappers/MemoryAllocatorBase.h"

namespace Telescope
{
constexpr const char* SURFACE_MEMORY_TAG = "telescope-surface";

enum class SurfacePixelFormat
{
	PixelFormatARGB32,
	PixelFormatSupportCount,
};

inline int bytesPerPixel(SurfacePixelFormat format)
{
	if (format == SurfacePixelFormat::PixelFormatARGB32)
	{
		return 4;
	}
	return 0;
}

struct SurfaceDescriptor
{
	void* data;
	int width;
	int height;
	int stride;
	SurfacePixelFormat pixelFormat;
};

struct SurfaceRegion
{
	SurfaceRegion(int x, int y, int w, int h)
		:mx(x), my(y), mWidth(w), mHeight(h)
	{
	}

	int mx,my,mWidth,mHeight;
};

class Surface
{
public:
	Surface( SurfacePixelFormat format = SurfacePixelFormat::PixelFormatARGB32 );
	~Surface();

	void setSize( int w, int h );
	void reset();
	void getData( SurfaceDescriptor& description, const SurfaceRegion* region = nullptr );

private:
	int getDataSize();
	void* mData;
	int mWidth;
	int mHeight;
	SurfacePixelFormat mFormat;
};
}
#endif

==> telescope.1.15.zip: source/Telescope/include/TelescopeSurface.h <==
/*
 * Copyright (C) 2020 Activision Publishing, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * 3. Neither the name of Activision Publishing, Inc. nor the names of
 *    its contributors may be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef TELESCOPESURFACE_INCLUDE
#define TELESCOPESURFACE_INCLUDE

#include "ClientWrappers/MemoryAllocatorBase.h"

namespace Telescope
{
enum class SurfacePixelFormat
{
	PixelFormatARGB32,
	PixelFormatSupportCount,
};

inline int bytesPerPixel( SurfacePixelFormat format )
{
	if ( format == SurfacePixelFormat::PixelFormatARGB32 )
	{
		return 4;
	}
	return 0;
}

struct SurfaceDescriptor
{
	void *data;
	int width;
	int height;
	int stride;
	SurfacePixelFormat pixelFormat;
};

struct SurfaceRegion
{
	SurfaceRegion( int x, int y, int w, int h )
		: mx( x ), my( y ), mWidth( w ), mHeight( h )
	{
	}

	int mx, my, mWidth, mHeight;
};

class Surface
{
public:
	Surface( SurfacePixelFormat format = SurfacePixelFormat::PixelFormatARGB32 );
	~Surface();

	void setSize( int w, int h );
	void reset();
	void getData( SurfaceDescriptor &description, const SurfaceRegion *region = nullptr );

private:
	int getDataSize();
	void *mData;
	int mWidth;
	int mHeight;
	SurfacePixelFormat mFormat;
};
} // namespace Telescope
#endif // #ifndef TELESCOPESURFACE_INCLUDE
